=======
History
=======

0.1.4 (2019-11-18)
------------------

* Fix PyPI versioning

0.1.3 (2019-11-18)
------------------

* Release on PyPI

0.1.2 (2019-11-17)
------------------

* Enable basic command line query of Companies House
* Enable codecov

0.1.1 (2019-11-13)
------------------
* Improve function and variable names
* Expand docstring of companies_house_query
* Expand type hinting
* pytest-remotedata plugin test for optional real query test

0.1.0 (2019-11-11)
------------------

* First release on PyPI.
* Basic tests of querying from companies house
